@@ -2,6 +2,7 @@
 
 import streamlit as st
 from typing import Mapping, Iterable
+from meshed.itools import successors
 
 DFLT_VALS = {
     int: 0,
@@ -110,15 +111,27 @@ def display_factory(dag, nodes, funcs, values, arg_types, ranges, col):
                     st.number_input(node, **st_kwargs)
             else:
                 st.number_input(node, **st_kwargs)
+        st.button(
+            'Reload DAG from root nodes', on_click=reload_nodes, args=(dag, funcs)
+        )
 
 
-def update_nodes(dag, funcs):
+def reload_nodes(dag, funcs):
     for node in dag.var_nodes:
         if node not in dag.roots:
-            args = [st.session_state[arg] for arg in list(funcs[node].src_names.keys())]
+            args = [st.session_state[arg] for arg in list(funcs[node].sig.names)]
             st.session_state[node] = funcs[node].func(*args)
 
 
+def update_nodes(dag, node_ch, funcs):
+    sub_nodes = [
+        node for node in list(successors(dag.graph, node_ch)) if isinstance(node, str)
+    ]
+    for node in sub_nodes:
+        args = [st.session_state[arg] for arg in list(funcs[node].sig.names)]
+        st.session_state[node] = funcs[node].func(*args)
+
+
 def get_values(dag, funcs):
     defaults = dict()
     for name in dag.sig.names:
